@@ -1,35 +1,30 @@
-"""
-
-"""
+import logging
 
 """
+_logging.py
 websocket - WebSocket client library for Python
 
-Copyright (C) 2010 Hiroki Ohtani(liris)
+Copyright 2023 engn33r
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    http://www.apache.org/licenses/LICENSE-2.0
 
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 """
-import logging
 
 _logger = logging.getLogger('websocket')
 try:
     from logging import NullHandler
 except ImportError:
     class NullHandler(logging.Handler):
-        def emit(self, record):
+        def emit(self, record) -> None:
             pass
 
 _logger.addHandler(NullHandler())
@@ -40,7 +35,9 @@ __all__ = ["enableTrace", "dump", "error", "warning", "debug", "trace",
            "isEnabledForError", "isEnabledForDebug", "isEnabledForTrace"]
 
 
-def enableTrace(traceable, handler = logging.StreamHandler()):
+def enableTrace(traceable: bool,
+                handler: logging.StreamHandler = logging.StreamHandler(),
+                level: str = "DEBUG") -> None:
     """
     Turn on/off the traceability.
 
@@ -53,38 +50,44 @@ def enableTrace(traceable, handler = logging.StreamHandler()):
     _traceEnabled = traceable
     if traceable:
         _logger.addHandler(handler)
-        _logger.setLevel(logging.DEBUG)
+        _logger.setLevel(getattr(logging, level))
 
-def dump(title, message):
+
+def dump(title: str, message: str) -> None:
     if _traceEnabled:
         _logger.debug("--- " + title + " ---")
         _logger.debug(message)
         _logger.debug("-----------------------")
 
 
-def error(msg):
+def error(msg: str) -> None:
     _logger.error(msg)
 
 
-def warning(msg):
+def warning(msg: str) -> None:
     _logger.warning(msg)
 
 
-def debug(msg):
+def debug(msg: str) -> None:
     _logger.debug(msg)
 
 
-def trace(msg):
+def info(msg: str) -> None:
+    _logger.info(msg)
+
+
+def trace(msg: str) -> None:
     if _traceEnabled:
         _logger.debug(msg)
 
 
-def isEnabledForError():
+def isEnabledForError() -> bool:
     return _logger.isEnabledFor(logging.ERROR)
 
 
-def isEnabledForDebug():
+def isEnabledForDebug() -> bool:
     return _logger.isEnabledFor(logging.DEBUG)
 
-def isEnabledForTrace():
+
+def isEnabledForTrace() -> bool:
     return _traceEnabled
